# Reference

## CeleryTaskModel

::: django_celery_boost.models.CeleryTaskModel
    handler: python
    options:
        annotations_path: brief
        docstring_style: google
        heading_level: 3
        separate_signature: true
        show_bases: false
        show_root_heading: false
        show_root_toc_entry: false
        show_root_full_path: false
        show_root_members_full_path: false
        show_category_heading: true
        show_signature: true
        show_signature_annotations: true
        show_symbol_type_heading: true
        show_source: false  
        unwrap_annotated: false
